=================================
Flask-APScheduler
=================================
Flask-APScheduler is a Flask extension which adds support for the APScheduler.

|Version|

Features
===============
- Loads scheduler configuration from Flask configuration.
- Loads job definitions from Flask configuration.
- Allows to specify the hostname which the scheduler will run on.
- Provides a http API to get and run the scheduled jobs.

Documentation
===============
Soon... take a look at the examples_ to see how it works.

Installation
===============
You can install Flask-APScheduler via Python Package Index (PyPI_),::

    $ pip install Flask-APScheduler

Feedback
===============
Please use the Issues_ for feature requests and troubleshooting usage.

.. |Version| image:: https://badge.fury.io/py/flask-apscheduler.svg?
   :target: http://badge.fury.io/py/flask-apscheduler

.. _examples: https://github.com/viniciuschiele/flask-apscheduler/tree/master/examples

.. _PyPi: https://pypi.python.org/pypi/Flask-APScheduler

.. _Issues: https://github.com/viniciuschiele/flask-apscheduler/issues

